/* ***** BEGIN LICENSE BLOCK *****
 *   Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Thumbs Down.
 *
 * The Initial Developer of the Original Code is
 * Atte Kemppilä.
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 * 
 * ***** END LICENSE BLOCK ***** */


const TOPIC_DB_CHANGED = "thumbsdown-db-changed";

var stringBundle;


function $(id)
{
    return document.getElementById(id);
}

function _(s, arg)
{
    // re-assign on first call
    if (stringBundle instanceof Ci.nsIStringBundle)
        _ = getString_nsIStringBundle;
    else
        _ = getString_stringBundle;
    return _(s, arg);
}

function getString_stringBundle(s, arg)
{
    if (arg === undefined)
        return stringBundle.getString(s);
    else
        return stringBundle.getFormattedString(s, arg);
}

// use chrome://global/content/strres.js to initialize stringBundle
function getString_nsIStringBundle(s, arg)
{
    if (arg === undefined)
        return stringBundle.GetStringFromName(s);
    else
        return stringBundle.formatStringFromName(s, arg, arg.length);
}

function trim(s)
{
    return s.replace(/^\s+|\s+$/g, "");
}

function fireDbChanged(table, type, id)
{
    table = (table ? table : "");
    type = (type ? type : "");
    id = (id ? id : "");
    var obsSvc = Cc["@mozilla.org/observer-service;1"].getService(Ci.nsIObserverService);
    var data = table + ":" + type + ":" + id;
    obsSvc.notifyObservers(this, TOPIC_DB_CHANGED, data);
}

function loadContent(url)
{
    var ioSvc = Cc["@mozilla.org/network/io-service;1"].getService(Ci.nsIIOService);
    var stream = Cc["@mozilla.org/scriptableinputstream;1"].getService(Ci.nsIScriptableInputStream);
    var channel = ioSvc.newChannel(url, null, null);
    var input = channel.open();
    stream.init(input);
    var content = stream.read(input.available());
    stream.close();
    input.close();
    return content;
}

function openUrl(url)
{
    var windowMediator = Cc["@mozilla.org/appshell/window-mediator;1"].getService(Ci.nsIWindowMediator);
    var win = windowMediator.getMostRecentWindow("navigator:browser");
    if (! win)
        return;
    var browser = win.getBrowser();
    browser.selectedTab = browser.addTab(url);
}

function openPrefWindow()
{
    var windowUrl = "chrome://thumbsdown/content/options.xul";
    var windowName = "thumbsdown_prefwindow";
    var windowMediator = Cc["@mozilla.org/appshell/window-mediator;1"].getService(Ci.nsIWindowMediator);
    var win = windowMediator.getMostRecentWindow(windowName);
    if (win)
        win.focus();
    else
    {
        // open window like firefox does it
        var instantApply = nsPreferences.getBoolPref("browser.preferences.instantApply", false);
        var features = "chrome,titlebar,toolbar,centerscreen," + (instantApply ? "dialog=no" : "modal");
        window.openDialog(windowUrl, windowName, features);
    }
}

function openScriptRunnerWindow(focus)
{
    var scriptRunner = Cc["@thumbsdown.mozdev.org/script-runner;1"].getService(Ci.nsISupports).wrappedJSObject;
    scriptRunner.openWindow(focus);
}
    
function schedule(obj, func, args, delay, type)
{
    var timer = Cc["@mozilla.org/timer;1"].createInstance(Ci.nsITimer);
    delay = ((delay !== undefined) ? delay : 0);
    type = ((type !== undefined) ? type : timer.TYPE_ONE_SHOT);
    var callback = {notify: function(timer) { func.apply(obj, args); }};
    timer.initWithCallback(callback, delay, type);
    return timer;
}

function getCallback(obj, func)
{
    var callback = function() { func.apply(obj, arguments); };
    return callback;
}

function getHandler(name, obj, func)
{
    var handler = {};
    handler[name] = getCallback(obj, func);
    return handler;
}
